@@ -136,7 +136,9 @@ class NexusWriter:
                 dset_shape = (len(_scan_range),) + tuple(self.detector.image_size)
 
             generate_image_data(dset_shape, self._datafile)
-            nxdata["data"] = h5py.ExternalLink(self._datafile, "data")
+            # nxdata["data"] = h5py.ExternalLink(self._datafile, "data")
+            # use a relative path
+            nxdata["data"] = h5py.ExternalLink(os.path.basename(self._datafile), "data")
         else:
             # TODO This needs some serious rethinking at some point
             dirname = os.path.dirname(self._nxs.filename)
@@ -377,9 +379,8 @@ class NexusWriter:
 
     def write_NXinstrument(self, nxentry):
         nxinstr = nxentry.create_group("instrument")
-        create_attributes(
-            nxinstr, ("NX_class", "short_name"), ("NXinstrument", "beamline")
-        )
+        bl = self.beamline.beamline_name
+        create_attributes(nxinstr, ("NX_class", "short_name"), ("NXinstrument", bl))
 
         # NXattenuator: /entry/instrument/attenuator
         attenuator = self.attenuator
